@@ -1,7 +1,7 @@
 package Perinci::Access::Lite;
 
-our $DATE = '2015-12-17'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -162,8 +162,8 @@ sub request {
     } elsif ($url =~ m!\Ahttps?:/(/?)!i) {
         my $is_unix = !$1;
         my $ht;
-        require JSON;
-        state $json = JSON->new->allow_nonref;
+        require JSON::MaybeXS;
+        state $json = JSON::MaybeXS->new->allow_nonref;
         if ($is_unix) {
             require HTTP::Tiny::UNIX;
             $ht = HTTP::Tiny::UNIX->new;
@@ -216,7 +216,7 @@ Perinci::Access::Lite - A lightweight Riap client library
 
 =head1 VERSION
 
-This document describes version 0.12 of Perinci::Access::Lite (from Perl distribution Perinci-Access-Lite), released on 2015-12-17.
+This document describes version 0.13 of Perinci::Access::Lite (from Perl distribution Perinci-Access-Lite), released on 2016-03-16.
 
 =head1 DESCRIPTION
 
@@ -260,16 +260,6 @@ This includes: Riap::Simple over pipe/TCP socket.
 
 =back
 
-=head1 ATTRIBUTES
-
-=head2 riap_version => float (default: 1.1)
-
-=head1 METHODS
-
-=head2 new(%attrs) => obj
-
-=head2 $pa->request($action, $url, $extra) => hash
-
 =head1 ADDED RESULT METADATA
 
 This class might add the following property/attribute in result metadata:
@@ -279,9 +269,15 @@ This class might add the following property/attribute in result metadata:
 If result's schema type is C<buf>, then this class will set this attribute to
 true, to give hints to result formatters.
 
-=head1 SEE ALSO
+=head1 ATTRIBUTES
 
-L<Perinci::Access>
+=head2 riap_version => float (default: 1.1)
+
+=head1 METHODS
+
+=head2 new(%attrs) => obj
+
+=head2 $pa->request($action, $url, $extra) => hash
 
 =head1 HOMEPAGE
 
@@ -299,13 +295,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci::Access>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
